@@ -4,10 +4,14 @@ import time
 import unittest
 
 from solcx import compile_files
-from web3 import Web3, HTTPProvider, EthereumTesterProvider
+from web3 import Web3
+from web3.providers import HTTPProvider
+from web3.providers.eth_tester import EthereumTesterProvider
+from web3.types import TxReceipt
+from eth_typing import Address, ChecksumAddress, HexAddress, HexStr
 from web3.contract import Contract
 from web3.middleware import geth_poa_middleware
-from web3.utils.transactions import wait_for_transaction_receipt
+from web3._utils.transactions import wait_for_transaction_receipt
 from hmt_escrow.kvstore_abi import abi as kvstore_abi
 from typing import Dict, List, Tuple, Optional, Any
 
@@ -53,13 +57,13 @@ def get_w3() -> Web3:
     endpoint = os.getenv("HMT_ETH_SERVER", "http://localhost:8545")
     if not endpoint:
         LOG.error("Using EthereumTesterProvider as we have no HMT_ETH_SERVER")
-    provider = HTTPProvider(endpoint) if endpoint else EthereumTesterProvider
+    provider = HTTPProvider(endpoint) if endpoint else EthereumTesterProvider()
     w3 = Web3(provider)
-    w3.middleware_stack.inject(geth_poa_middleware, layer=0)
+    w3.middleware_onion.inject(geth_poa_middleware, layer=0)
     return w3
 
 
-def handle_transaction(txn_func, *args, **kwargs) -> AttributeDict:
+def handle_transaction(txn_func, *args, **kwargs) -> TxReceipt:
     """Handles a transaction that updates the contract state by locally
     signing, building, sending the transaction and returning a transaction
     receipt.
@@ -119,7 +123,7 @@ def get_hmtoken(hmtoken_addr=HMTOKEN_ADDR) -> Contract:
     """Retrieve the HMToken contract from a given address.
 
     >>> type(get_hmtoken())
-    <class 'web3.utils.datatypes.Contract'>
+    <class 'web3._utils.datatypes.Contract'>
 
     Returns:
         Contract: returns the HMToken solidity contract.
@@ -148,7 +152,7 @@ def get_escrow(escrow_addr: str) -> Contract:
     >>> job.launch(rep_oracle_pub_key)
     True
     >>> type(get_escrow(job.job_contract.address))
-    <class 'web3.utils.datatypes.Contract'>
+    <class 'web3._utils.datatypes.Contract'>
 
     Args:
         escrow_addr (str): an ethereum address of the escrow contract.
@@ -162,11 +166,14 @@ def get_escrow(escrow_addr: str) -> Contract:
     contract_interface = get_contract_interface(
         "{}/Escrow.sol:Escrow".format(CONTRACT_FOLDER)
     )
-    escrow = w3.eth.contract(address=escrow_addr, abi=contract_interface["abi"])
+    escrow = w3.eth.contract(
+        address=ChecksumAddress(HexAddress(HexStr(escrow_addr))),
+        abi=contract_interface["abi"],
+    )
     return escrow
 
 
-def get_factory(factory_addr: Optional[str]) -> Contract:
+def get_factory(factory_addr: str) -> Contract:
     """Retrieve the EscrowFactory contract from a given address.
 
     >>> credentials = {
@@ -175,7 +182,7 @@ def get_factory(factory_addr: Optional[str]) -> Contract:
     ... }
     >>> job = Job(credentials=credentials, escrow_manifest=manifest)
     >>> type(get_factory(job.factory_contract.address))
-    <class 'web3.utils.datatypes.Contract'>
+    <class 'web3._utils.datatypes.Contract'>
 
     Args:
         factory_addr (str): the ethereum address of the Escrow contract.
@@ -189,7 +196,8 @@ def get_factory(factory_addr: Optional[str]) -> Contract:
         "{}/EscrowFactory.sol:EscrowFactory".format(CONTRACT_FOLDER)
     )
     escrow_factory = w3.eth.contract(
-        address=factory_addr, abi=contract_interface["abi"]
+        address=ChecksumAddress(HexAddress(HexStr(factory_addr))),
+        abi=contract_interface["abi"],
     )
     return escrow_factory
 
@@ -220,7 +228,7 @@ def deploy_factory(gas: int = GAS_LIMIT, **credentials) -> str:
     txn_info = {"gas_payer": gas_payer, "gas_payer_priv": gas_payer_priv, "gas": gas}
     txn_receipt = handle_transaction(txn_func, *func_args, **txn_info)
     contract_addr = txn_receipt["contractAddress"]
-    return contract_addr
+    return str(contract_addr)
 
 
 def get_pub_key_from_addr(wallet_addr: str) -> bytes:
@@ -274,7 +282,7 @@ def get_pub_key_from_addr(wallet_addr: str) -> bytes:
     return bytes(addr_pub_key, encoding="utf-8")
 
 
-def set_pub_key_at_addr(pub_key: str) -> Dict[str, Any]:
+def set_pub_key_at_addr(pub_key: str) -> TxReceipt:
     """
     Given a public key, this function will use the eth-kvstore to reach out to the blockchain
     and set the key `hmt_pub_key` on the callers kvstore collection of values, equivalent to the
